---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

## Describe the bug ##
Please describe the bug you're experiencing is precise as possible.

## To Reproduce ##
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

## Expected behaviour ##
A clear and concise description of what you expected to happen.

## Actual behavior, stacktrace or logfile ##
Please describe the expected behavior here. If there is a stacktrace, please paste it here. If there is no stacktrace printed, please upload the logfile which was stored in the `tmp_folder`

## Environment and installation: ##

Please give details about your installation:

* OS
* Is your installation in a virtual environment or conda environment?
* Python version
* module/package/library version